@@ -8,7 +8,7 @@ use Data::Dumper qw/Dumper/;
 use Data::SExpression qw/consp scalarp/;
 use Scalar::Util qw/looks_like_number/;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.002';
 
 our %TYPES = (
 	LIST => 0,
@@ -196,11 +196,121 @@ expression to be evaluated).
 In normal use a single S-expression will be supplied, representing an
 entire program.
 
-The B<parse_and_print> method takes such a string and prints a block
-of verilog code assigning the memory contents to an array named
-C<mem>.
+The C<tag> is either a number, a type, or a primitive.
+The available types are:
 
-More documentation and features to follow.
+=over
+
+=item LIST
+
+=item SYMBOL (syn. NUMBER)
+
+=item VAR (syn. VARIABLE)
+
+=item CLOSURE
+
+=item PROC (syn. PROCEDURE)
+
+=item IF (syn. COND, CONDITIONAL)
+
+=item CALL
+
+=item QUOTE (syn. QUOTED)
+
+=back
+
+The available primitives are:
+
+=over
+
+=item MORE
+
+=item CAR
+
+=item CDR
+
+=item CONS
+
+=item ATOM
+
+=item PROGN
+
+=item MAKELIST
+
+=item FUNCALL
+
+=back
+
+The following methods are available:
+
+=over
+
+=item App::Scheme79asm->B<new>([key => value, key => value, ...])
+
+Create a new assembler object. Takes a list of keys and values, here
+are the possible keys:
+
+=over
+
+=item type_bits
+
+=item address_bits
+
+A word is made of a type and an address, with the type occupying the
+most significant C<type_bits> (default 3) bits, and the address
+occupying the least significant C<address_bits> (default 8) bits.
+Therefore the word size is C<type_bits + address_bits> (default 13).
+
+=item freeptr
+
+A pointer to the last used byte in memory (default 6). The program
+will be laid out starting with location C<freeptr + 1>.
+
+=item memory
+
+The initial contents of the memory. Note that locations 4, 5, 6 will
+be overwritten, as will every location larger than the value of
+C<freeptr>.
+
+=item comment
+
+The initial comments for memory entries. C<< $comment->[$i] >> is the
+comment for C<< $memory->[$i] >>.
+
+=item symbols
+
+The initial symbol map, as a hashref from symbol name to the index of
+that symbol. Defaults to C<< {NIL => 0, T => 1} >>.
+
+=item nsymbols
+
+The number of distinct symbols in the initial symbols map (default 2).
+
+=back
+
+=item $asm->B<parse>(I<$string>)
+
+Parse a sequence of S-expressions and lay it out in memory.
+Can be called multiple times to lay out multiple sequences of
+S-expressions one after another.
+
+=item $asm->B<finish>
+
+Move the last pointer to position 5, and put the free pointer at
+position 4. After all sequences of S-expressions have been given to
+B<parse>, this method should be called.
+
+=item $asm->B<print>([I<$fh>])
+
+Print a block of Verilog code assigning the memory contents to an
+array named C<mem> to the given filehandle (default STDOUT).
+
+=item $asm->B<parse_and_print>(I<$string>[, I<$fh>])
+
+Convenience method that calls B<parse>($string), B<finish>, and then
+B<print>($fh).
+
+=back
 
 =head1 SEE ALSO
 
